@@ -74,13 +74,14 @@ public:
 
 	drumkv1_sample *sample() const;
 
-	void setReverse(bool bReverse);
+	void setReverse(bool bReverse, bool bSync = false);
 	bool isReverse() const;
 
-	void setOffset(bool bOffset);
+	void setOffset(bool bOffset, bool bSync = false);
 	bool isOffset() const;
 
-	void setOffsetRange(uint32_t iOffsetStart, uint32_t iOffsetEnd);
+	void setOffsetRange(
+		uint32_t iOffsetStart, uint32_t iOffsetEnd, bool bSync = false);
 	uint32_t offsetStart() const;
 	uint32_t offsetEnd() const;
 
@@ -92,6 +93,8 @@ public:
 		GEN1_SAMPLE = 0,
 		GEN1_REVERSE,
 		GEN1_OFFSET,
+		GEN1_OFFSET_1,
+		GEN1_OFFSET_2,
 		GEN1_GROUP,
 		GEN1_COARSE,
 		GEN1_FINE,
@@ -175,6 +178,9 @@ public:
 	float paramValue(ParamIndex index) const;
 
 	void resetParamValues(bool bSwap);
+
+	bool running(bool on);
+
 	void reset();
 
 	drumkv1_controls *controls() const;
@@ -183,8 +189,6 @@ public:
 	void process_midi(uint8_t *data, uint32_t size);
 	void process(float **ins, float **outs, uint32_t nframes);
 
-	bool sampleOffsetTest() const;
-
 	virtual void updatePreset(bool bDirty) = 0;
 
 	void midiInEnabled(bool on);
@@ -240,7 +244,13 @@ public:
 
 	void resetParamValues(bool bSwap);
 
-	bool sampleOffsetTest();
+	void sampleReverseTest();
+	void sampleReverseSync(bool bSync);
+
+	void sampleOffsetTest();
+	void sampleOffsetSync(bool bSync);
+
+	void updateEnvTimes();
 
 private:
 
