@@ -312,9 +312,10 @@ void drumkv1_config::load (void)
 	sSampleDir = QSettings::value("/SampleDir").toString();
 	iKnobDialMode = QSettings::value("/KnobDialMode", 0).toInt();
 	iKnobEditMode = QSettings::value("/KnobEditMode", 0).toInt();
+	iFrameTimeFormat = QSettings::value("/FrameTimeFormat", 0).toInt();
+	bUseGMDrumNames = QSettings::value("/UseGMDrumNames", true).toBool();
 	bControlsEnabled = QSettings::value("/ControlsEnabled", false).toBool();
 	bProgramsEnabled = QSettings::value("/ProgramsEnabled", false).toBool();
-	bUseGMDrumNames = QSettings::value("/UseGMDrumNames", true).toBool();
 	QSettings::endGroup();
 
 	QSettings::beginGroup("/Dialogs");
@@ -353,9 +354,10 @@ void drumkv1_config::save (void)
 	QSettings::setValue("/SampleDir", sSampleDir);
 	QSettings::setValue("/KnobDialMode", iKnobDialMode);
 	QSettings::setValue("/KnobEditMode", iKnobEditMode);
+	QSettings::setValue("/FrameTimeFormat", iFrameTimeFormat);
+	QSettings::setValue("/UseGMDrumNames", bUseGMDrumNames);
 	QSettings::setValue("/ControlsEnabled", bControlsEnabled);
 	QSettings::setValue("/ProgramsEnabled", bProgramsEnabled);
-	QSettings::setValue("/UseGMDrumNames", bUseGMDrumNames);
 	QSettings::endGroup();
 
 	QSettings::beginGroup("/Dialogs");
