@@ -64,6 +64,12 @@ public:
 	int iKnobDialMode;
 	int iKnobEditMode;
 
+	// Special time-formatted spinbox option.
+	int iFrameTimeFormat;
+
+	// Whether to display GM Standard drum-note/key names.
+	bool bUseGMDrumNames;
+
 	// Special persistent options.
 	bool bControlsEnabled;
 	bool bProgramsEnabled;
@@ -75,9 +81,6 @@ public:
 	// Custom widget style theme.
 	QString sCustomStyleTheme;
 
-	// Whether to display GM Standard drum-note/key names.
-	bool bUseGMDrumNames;
-
 	// Micro-tuning options.
 	bool    bTuningEnabled;
 	float   fTuningRefPitch;
