@@ -1,7 +1,7 @@
 // drumkv1_jack.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2017, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2018, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -118,6 +118,9 @@ class drumkv1widget_jack;
 class drumkv1_nsm;
 #endif
 
+#ifdef HAVE_SIGNAL_H
+class QSocketNotifier;
+#endif
 
 class drumkv1_jack_application : public QObject
 {
@@ -147,6 +150,11 @@ protected slots:
 
 #endif	// CONFIG_NSM
 
+#ifdef HAVE_SIGNAL_H
+	// SIGTERM signal handler.
+	void sigterm_handler();
+#endif
+
 protected:
 
 	// Argument parser method.
@@ -168,6 +176,10 @@ private:
 #ifdef CONFIG_NSM
 	drumkv1_nsm *m_pNsmClient;
 #endif
+
+#ifdef HAVE_SIGNAL_H
+	QSocketNotifier *m_pSigtermNotifier;
+#endif
 };
 
 
