@@ -1,7 +1,7 @@
 // drumkv1widget_config.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2017, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2018, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -32,6 +32,9 @@ namespace Ui { class drumkv1widget_config; }
 
 class drumkv1_ui;
 
+class QComboBox;
+class QFileInfo;
+
 
 //----------------------------------------------------------------------------
 // drumkv1widget_config -- UI wrapper form.
@@ -75,6 +78,11 @@ protected slots:
 	void controlsEnabled(bool);
 	void programsEnabled(bool);
 
+	void tuningRefNoteClicked();
+	void tuningScaleFileClicked();
+	void tuningKeyMapFileClicked();
+
+	void tuningChanged();
 	void controlsChanged();
 	void programsChanged();
 	void optionsChanged();
@@ -85,6 +93,14 @@ protected slots:
 
 protected:
 
+	// Combo box history persistence helper prototypes.
+	void loadComboBoxHistory(QComboBox *pComboBox);
+	void saveComboBoxHistory(QComboBox *pComboBox);
+
+	// Combo box settter/gettter helper prototypes.
+	bool setComboBoxCurrentItem(QComboBox *pComboBox, const QFileInfo& info);
+	QString comboBoxCurrentItem(QComboBox *pComboBox);
+
 	// stabilizer.
 	void stabilize();
 
@@ -98,6 +114,7 @@ private:
 	drumkv1_ui *m_pDrumkUi;
 
 	// Dialog dirty flag.
+	int m_iDirtyTuning;
 	int m_iDirtyControls;
 	int m_iDirtyPrograms;
 	int m_iDirtyOptions;
